@@ -226,17 +226,17 @@ gPodderSettings = {
     'youtube_preferred_fmt_id': (int, 18,
       ('The preferred video format that should be downloaded from YouTube.')),
 
-    # my.gpodder.org general settings
+    # gpodder.net general settings
     'mygpo_username': (str, '',
       ("The user's gPodder web services username.")),
     'mygpo_password': (str, '',
       ("The user's gPodder web services password.")),
     'mygpo_enabled': (bool, False,
       ("Synchronize subscriptions with the web service.")),
-    'mygpo_server': (str, 'my.gpodder.org',
+    'mygpo_server': (str, 'gpodder.net',
       ('The hostname of the mygpo server in use.')),
 
-    # my.gpodder.org device-specific settings
+    # gpodder.net device-specific settings
     'mygpo_device_uid': (str, util.get_hostname(),
       ("The UID that is assigned to this installation.")),
     'mygpo_device_caption': (str, _('gPodder on %s') % util.get_hostname(),
